import { ParserRuleContext } from 'antlr4ts';
import { AbstractParseTreeVisitor } from 'antlr4ts/tree/AbstractParseTreeVisitor';
import * as SP from './antlr/SolidityParser';
import { SolidityVisitor } from './antlr/SolidityVisitor';
import { ParseOptions } from './types';
import * as AST from './ast-types';
export declare class ASTBuilder extends AbstractParseTreeVisitor<AST.ASTNode> implements SolidityVisitor<AST.ASTNode | AST.ASTNode[]> {
    options: ParseOptions;
    result: AST.SourceUnit | null;
    private _currentContract?;
    constructor(options: ParseOptions);
    defaultResult(): AST.ASTNode;
    aggregateResult(): AST.ASTNode;
    visitSourceUnit(ctx: SP.SourceUnitContext): AST.SourceUnit;
    visitContractPart(ctx: SP.ContractPartContext): AST.ASTNode;
    visitContractDefinition(ctx: SP.ContractDefinitionContext): AST.ContractDefinition;
    visitStateVariableDeclaration(ctx: SP.StateVariableDeclarationContext): AST.StateVariableDeclaration;
    visitVariableDeclaration(ctx: SP.VariableDeclarationContext): AST.VariableDeclaration;
    visitVariableDeclarationStatement(ctx: SP.VariableDeclarationStatementContext): AST.VariableDeclarationStatement;
    visitStatement(ctx: SP.StatementContext): AST.Statement;
    visitSimpleStatement(ctx: SP.SimpleStatementContext): AST.SimpleStatement;
    visitEventDefinition(ctx: SP.EventDefinitionContext): AST.EventDefinition;
    visitBlock(ctx: SP.BlockContext): AST.Block;
    visitParameter(ctx: SP.ParameterContext): AST.VariableDeclaration;
    visitFunctionDefinition(ctx: SP.FunctionDefinitionContext): AST.FunctionDefinition;
    visitEnumDefinition(ctx: SP.EnumDefinitionContext): AST.EnumDefinition;
    visitEnumValue(ctx: SP.EnumValueContext): AST.EnumValue;
    visitElementaryTypeName(ctx: SP.ElementaryTypeNameContext): AST.ElementaryTypeName;
    visitIdentifier(ctx: SP.IdentifierContext): AST.Identifier;
    visitTypeName(ctx: SP.TypeNameContext): AST.TypeName;
    visitUserDefinedTypeName(ctx: SP.UserDefinedTypeNameContext): AST.UserDefinedTypeName;
    visitUsingForDeclaration(ctx: SP.UsingForDeclarationContext): AST.UsingForDeclaration;
    visitPragmaDirective(ctx: SP.PragmaDirectiveContext): AST.PragmaDirective;
    visitInheritanceSpecifier(ctx: SP.InheritanceSpecifierContext): AST.InheritanceSpecifier;
    visitModifierInvocation(ctx: SP.ModifierInvocationContext): AST.ModifierInvocation;
    visitTypeNameExpression(ctx: SP.TypeNameExpressionContext): AST.TypeNameExpression;
    visitFunctionTypeName(ctx: SP.FunctionTypeNameContext): AST.FunctionTypeName;
    visitFunctionTypeParameter(ctx: SP.FunctionTypeParameterContext): AST.VariableDeclaration;
    visitThrowStatement(ctx: SP.ThrowStatementContext): AST.ThrowStatement;
    visitReturnStatement(ctx: SP.ReturnStatementContext): AST.ReturnStatement;
    visitEmitStatement(ctx: SP.EmitStatementContext): AST.EmitStatement;
    visitFunctionCall(ctx: SP.FunctionCallContext): AST.FunctionCall;
    visitStructDefinition(ctx: SP.StructDefinitionContext): AST.StructDefinition;
    visitWhileStatement(ctx: SP.WhileStatementContext): AST.WhileStatement;
    visitDoWhileStatement(ctx: SP.DoWhileStatementContext): AST.DoWhileStatement;
    visitIfStatement(ctx: SP.IfStatementContext): AST.IfStatement;
    visitTryStatement(ctx: SP.TryStatementContext): AST.TryStatement;
    visitCatchClause(ctx: SP.CatchClauseContext): AST.CatchClause;
    visitExpressionStatement(ctx: SP.ExpressionStatementContext): AST.ExpressionStatement;
    visitNumberLiteral(ctx: SP.NumberLiteralContext): AST.NumberLiteral;
    visitMappingKey(ctx: SP.MappingKeyContext): AST.ElementaryTypeName | AST.UserDefinedTypeName;
    visitMapping(ctx: SP.MappingContext): AST.Mapping;
    visitModifierDefinition(ctx: SP.ModifierDefinitionContext): AST.ModifierDefinition;
    visitUncheckedStatement(ctx: SP.UncheckedStatementContext): AST.UncheckedStatement;
    visitExpression(ctx: SP.ExpressionContext): AST.Expression;
    visitNameValueList(ctx: SP.NameValueListContext): AST.NameValueList;
    visitFileLevelConstant(ctx: SP.FileLevelConstantContext): AST.FileLevelConstant;
    visitForStatement(ctx: SP.ForStatementContext): AST.ForStatement;
    visitHexLiteral(ctx: SP.HexLiteralContext): AST.HexLiteral;
    visitPrimaryExpression(ctx: SP.PrimaryExpressionContext): AST.PrimaryExpression;
    visitTupleExpression(ctx: SP.TupleExpressionContext): AST.TupleExpression;
    buildIdentifierList(ctx: SP.IdentifierListContext): (AST.VariableDeclaration | null)[];
    buildVariableDeclarationList(ctx: SP.VariableDeclarationListContext): Array<AST.VariableDeclaration | null>;
    visitImportDirective(ctx: SP.ImportDirectiveContext): AST.ImportDirective;
    buildEventParameterList(ctx: SP.EventParameterListContext): {
        type: string;
        typeName: AST.ASTNode;
        name: string | null;
        isStateVar: boolean;
        isIndexed: boolean;
    }[];
    visitReturnParameters(ctx: SP.ReturnParametersContext): AST.VariableDeclaration[];
    visitParameterList(ctx: SP.ParameterListContext): AST.VariableDeclaration[];
    visitInlineAssemblyStatement(ctx: SP.InlineAssemblyStatementContext): AST.InlineAssemblyStatement;
    visitAssemblyBlock(ctx: SP.AssemblyBlockContext): AST.AssemblyBlock;
    visitAssemblyItem(ctx: SP.AssemblyItemContext): AST.AssemblyItem;
    visitAssemblyExpression(ctx: SP.AssemblyExpressionContext): AST.AssemblyExpression;
    visitAssemblyCall(ctx: SP.AssemblyCallContext): AST.AssemblyCall;
    visitAssemblyLiteral(ctx: SP.AssemblyLiteralContext): AST.AssemblyLiteral;
    visitAssemblySwitch(ctx: SP.AssemblySwitchContext): AST.AssemblySwitch;
    visitAssemblyCase(ctx: SP.AssemblyCaseContext): AST.AssemblyCase;
    visitAssemblyLocalDefinition(ctx: SP.AssemblyLocalDefinitionContext): AST.AssemblyLocalDefinition;
    visitAssemblyFunctionDefinition(ctx: SP.AssemblyFunctionDefinitionContext): AST.AssemblyFunctionDefinition;
    visitAssemblyAssignment(ctx: SP.AssemblyAssignmentContext): AST.AssemblyAssignment;
    visitAssemblyMember(ctx: SP.AssemblyMemberContext): AST.AssemblyMemberAccess;
    visitLabelDefinition(ctx: SP.LabelDefinitionContext): AST.LabelDefinition;
    visitAssemblyStackAssignment(ctx: SP.AssemblyStackAssignmentContext): AST.AssemblyStackAssignment;
    visitAssemblyFor(ctx: SP.AssemblyForContext): AST.AssemblyFor;
    visitAssemblyIf(ctx: SP.AssemblyIfContext): AST.AssemblyIf;
    private _toText;
    private _stateMutabilityToText;
    private _loc;
    _range(ctx: ParserRuleContext): [number, number];
    private _addMeta;
    private _mapCommasToNulls;
}
